// 
// Copyright (C) 2009, GreatTradingSystems <www.greattradingsystems.com>.
// 
//
#region Using declarations
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Diagnostics.CodeAnalysis;
using System.Windows;
using System.Reflection;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.Tools;
using NinjaTrader.NinjaScript.DrawingTools;
using NinjaTrader.NinjaScript.Indicators;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.NinjaScript.Indicators
{
    /// <summary>
    /// This is a sample indicator plotting a HMA in three colors.
    /// </summary>
    public class HMAColourChange : Indicator
    {
		#region Variables
		private int		period	= 14;
		#endregion
		
        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        private void Initialize()
        {
			// Add one plot for every color you wish to use.
            AddPlot(new Stroke(Brushes.LimeGreen), PlotStyle.Line, "Rising");
            AddPlot(new Stroke(Brushes.Red), PlotStyle.Line, "Falling");
			AddPlot(new Stroke(Brushes.Yellow), PlotStyle.Line, "Neutral");
			
            Calculate	= Calculate.OnBarClose;
            IsOverlay				= true;
        }

        protected override void OnStateChange()
        {
            switch (State)
            {
                case State.SetDefaults:
                    Name = "HMAColourChange";
                    Description = "Sample HMA plotted with three colors.";
                    Initialize();
                    break;
             }
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			// Checks to make sure we have at least 1 bar before continuing
			if (CurrentBar < 1)
				return;
			
			// Plot green if the HMA is rising
			// Rising() returns true when the current value is greater than the value of the previous bar.
			if (IsRising(HMA(Period)))
			{
				// Connects the rising plot segment with the other plots
				RisingPlot[1] = HMA(Period)[1];
				
				// Adds the new rising plot line segment to the line
				RisingPlot[0] = HMA(Period)[0];
			}
			
			// Plot red if the HMA is falling
			// Falling() returns true when the current value is less than the value of the previous bar.
			else if (IsFalling(HMA(Period)))
			{
				// Connects the new falling plot segment with the rest of the line
				FallingPlot[1] = HMA(Period)[1];
				
				// Adds the new falling plot line segment to the line
				FallingPlot[0] = HMA(Period)[0];
			}
			
			// Plot yellow if the HMA is neutral
			else
			{
				// Connects the neutral plot segment with the rest of the line
				NeutralPlot[1] = HMA(Period)[1];
				
				// Adds the new neutral plot line segment to the line
				NeutralPlot[0] = HMA(Period)[0];
			}
        }

        #region Properties
		// Adds three DataSeries to store the values of the three plots added in Initialize()
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> RisingPlot
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> FallingPlot
        {
            get { return Values[1]; }
        }
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> NeutralPlot
        {
            get { return Values[2]; }
        }
		
		// Adds an input for the period of the SMA
		/// <summary>
		/// </summary>
		[NinjaScriptProperty]		
		[Display(Description = "Numbers of bars used for calculations", GroupName = "Parameters", Order = 1)]		
		public int Period
		{
			get { return period; }
			set { period = Math.Max(1, value); }
		}
        #endregion
    }
}

